@@ -5,6 +5,7 @@
 
 import platform
 import runpy
+import sysconfig
 import os
 import sys
 
@@ -13,9 +14,10 @@ if __name__ == "__main__":
     # Setup environment for what the RoboRIO python would have
     # -> strictly speaking we only care about platform.machine as that's what
     #    we're using in robotpy-meta, but the rest for completeness
-    platform.machine = lambda: "armv7l"
+    sysconfig.get_platform = lambda: "linux_roborio"
+    platform.machine = lambda: "roborio"
     platform.python_implementation = lambda: "CPython"
     platform.system = lambda: "Linux"
-    platform.python_version = lambda: "3.11.0"
+    platform.python_version = lambda: "3.12.0"
 
     runpy.run_module("pip", run_name="__main__")
